summaryrefslogtreecommitdiff
path: root/source3/libads
diff options
context:
space:
mode:
Diffstat (limited to 'source3/libads')
-rw-r--r--source3/libads/ldap.c5
1 files changed, 3 insertions, 2 deletions
diff --git a/source3/libads/ldap.c b/source3/libads/ldap.c
index 8039d3d1d4..15504a5202 100644
--- a/source3/libads/ldap.c
+++ b/source3/libads/ldap.c
@@ -1661,7 +1661,7 @@ char **ads_pull_strings_range(ADS_STRUCT *ads,
}
if (!attr) {
ber_free(ptr, 0);
/* nothing here - this feild is just empty */
*more_strings = False;
return NULL;
}
@@ -1720,7 +1720,8 @@ char **ads_pull_strings_range(ADS_STRUCT *ads,
if (*more_strings) {
*next_attribute = talloc_asprintf(mem_ctx,
- "member;range=%d-*",
+ "%s;range=%d-*",
+ field,
*num_strings);
if (!*next_attribute) {
@@ -1661,7 +1661,7 @@ char **ads_pull_strings_range(ADS_STRUCT *ads,
if (!attr) {
ber_free(ptr, 0);
- /* nothing here - this feild is just empty */
+ /* nothing here - this field is just empty */
*more_strings = False;
return NULL;